@@ -1,7 +1,7 @@
 package Complete::Riap;
 
-our $DATE = '2014-12-25'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-01-13'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,6 +48,9 @@ _
             schema => ['str*', in=>['function','package']], # XXX other types?
             summary => 'Filter by entity type',
         },
+        riap_client => {
+            schema => 'obj*',
+        },
     },
     result_naked => 1,
 };
@@ -81,10 +84,11 @@ sub complete_riap_url {
         list_func => sub {
             my ($path, $intdir, $isint) = @_;
 
-            state $pa = do {
+            state $default_pa = do {
                 require Perinci::Access;
                 Perinci::Access->new;
             };
+            my $pa = $args{riap_client} // $default_pa;
 
             $path = "/$path" unless $path =~ m!\A/!;
             my $riap_res = $pa->request(list => $path, {detail=>1});
@@ -120,7 +124,7 @@ Complete::Riap - Riap-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.02 of Complete::Riap (from Perl distribution Complete-Riap), released on 2014-12-25.
+This document describes version 0.03 of Complete::Riap (from Perl distribution Complete-Riap), released on 2015-01-13.
 
 =head1 SYNOPSIS
 
@@ -150,6 +154,8 @@ Whether to do case-insensitive search.
 
 =item * B<map_case> => I<bool>
 
+=item * B<riap_client> => I<obj>
+
 =item * B<type> => I<str>
 
 Filter by entity type.
@@ -158,14 +164,7 @@ Filter by entity type.
 
 =back
 
-Return value:
-
- (any)
-
-=head1 TODO
-
-'ci' option (this should perhaps be implemented in
-L<Perinci::Access::Schemeless>?).
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -189,7 +188,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
